Class: Aws::DevOpsGuru::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::DevOpsGuru::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-devopsguru/client.rb,
sig/client.rbs
Overview
An API client for DevOpsGuru. To construct a client, you need to configure a :region and :credentials.
client = Aws::DevOpsGuru::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddNotificationChannelResponseSuccess, _DeleteInsightResponseSuccess, _DescribeAccountHealthResponseSuccess, _DescribeAccountOverviewResponseSuccess, _DescribeAnomalyResponseSuccess, _DescribeEventSourcesConfigResponseSuccess, _DescribeFeedbackResponseSuccess, _DescribeInsightResponseSuccess, _DescribeOrganizationHealthResponseSuccess, _DescribeOrganizationOverviewResponseSuccess, _DescribeOrganizationResourceCollectionHealthResponseSuccess, _DescribeResourceCollectionHealthResponseSuccess, _DescribeServiceIntegrationResponseSuccess, _GetCostEstimationResponseSuccess, _GetResourceCollectionResponseSuccess, _ListAnomaliesForInsightResponseSuccess, _ListAnomalousLogGroupsResponseSuccess, _ListEventsResponseSuccess, _ListInsightsResponseSuccess, _ListMonitoredResourcesResponseSuccess, _ListNotificationChannelsResponseSuccess, _ListOrganizationInsightsResponseSuccess, _ListRecommendationsResponseSuccess, _PutFeedbackResponseSuccess, _RemoveNotificationChannelResponseSuccess, _SearchInsightsResponseSuccess, _SearchOrganizationInsightsResponseSuccess, _StartCostEstimationResponseSuccess, _UpdateEventSourcesConfigResponseSuccess, _UpdateResourceCollectionResponseSuccess, _UpdateServiceIntegrationResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_notification_channel(params = {}) ⇒ Types::AddNotificationChannelResponse
Adds a notification channel to DevOps Guru.
-
#delete_insight(params = {}) ⇒ Struct
Deletes the insight along with the associated anomalies, events and recommendations.
-
#describe_account_health(params = {}) ⇒ Types::DescribeAccountHealthResponse
Returns the number of open reactive insights, the number of open proactive insights, and the number of metrics analyzed in your Amazon Web Services account.
-
#describe_account_overview(params = {}) ⇒ Types::DescribeAccountOverviewResponse
For the time range passed in, returns the number of open reactive insight that were created, the number of open proactive insights that were created, and the Mean Time to Recover (MTTR) for all closed reactive insights.
-
#describe_anomaly(params = {}) ⇒ Types::DescribeAnomalyResponse
Returns details about an anomaly that you specify using its ID.
-
#describe_event_sources_config(params = {}) ⇒ Types::DescribeEventSourcesConfigResponse
Returns the integration status of services that are integrated with DevOps Guru as Consumer via EventBridge.
-
#describe_feedback(params = {}) ⇒ Types::DescribeFeedbackResponse
Returns the most recent feedback submitted in the current Amazon Web Services account and Region.
-
#describe_insight(params = {}) ⇒ Types::DescribeInsightResponse
Returns details about an insight that you specify using its ID.
-
#describe_organization_health(params = {}) ⇒ Types::DescribeOrganizationHealthResponse
Returns active insights, predictive insights, and resource hours analyzed in last hour.
-
#describe_organization_overview(params = {}) ⇒ Types::DescribeOrganizationOverviewResponse
Returns an overview of your organization's history based on the specified time range.
-
#describe_organization_resource_collection_health(params = {}) ⇒ Types::DescribeOrganizationResourceCollectionHealthResponse
Provides an overview of your system's health.
-
#describe_resource_collection_health(params = {}) ⇒ Types::DescribeResourceCollectionHealthResponse
Returns the number of open proactive insights, open reactive insights, and the Mean Time to Recover (MTTR) for all closed insights in resource collections in your account.
-
#describe_service_integration(params = {}) ⇒ Types::DescribeServiceIntegrationResponse
Returns the integration status of services that are integrated with DevOps Guru.
-
#get_cost_estimation(params = {}) ⇒ Types::GetCostEstimationResponse
Returns an estimate of the monthly cost for DevOps Guru to analyze your Amazon Web Services resources.
-
#get_resource_collection(params = {}) ⇒ Types::GetResourceCollectionResponse
Returns lists Amazon Web Services resources that are of the specified resource collection type.
-
#list_anomalies_for_insight(params = {}) ⇒ Types::ListAnomaliesForInsightResponse
Returns a list of the anomalies that belong to an insight that you specify using its ID.
-
#list_anomalous_log_groups(params = {}) ⇒ Types::ListAnomalousLogGroupsResponse
Returns the list of log groups that contain log anomalies.
-
#list_events(params = {}) ⇒ Types::ListEventsResponse
Returns a list of the events emitted by the resources that are evaluated by DevOps Guru.
-
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Returns a list of insights in your Amazon Web Services account.
-
#list_monitored_resources(params = {}) ⇒ Types::ListMonitoredResourcesResponse
Returns the list of all log groups that are being monitored and tagged by DevOps Guru.
-
#list_notification_channels(params = {}) ⇒ Types::ListNotificationChannelsResponse
Returns a list of notification channels configured for DevOps Guru.
-
#list_organization_insights(params = {}) ⇒ Types::ListOrganizationInsightsResponse
Returns a list of insights associated with the account or OU Id.
-
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Returns a list of a specified insight's recommendations.
-
#put_feedback(params = {}) ⇒ Struct
Collects customer feedback about the specified insight.
-
#remove_notification_channel(params = {}) ⇒ Struct
Removes a notification channel from DevOps Guru.
-
#search_insights(params = {}) ⇒ Types::SearchInsightsResponse
Returns a list of insights in your Amazon Web Services account.
-
#search_organization_insights(params = {}) ⇒ Types::SearchOrganizationInsightsResponse
Returns a list of insights in your organization.
-
#start_cost_estimation(params = {}) ⇒ Struct
Starts the creation of an estimate of the monthly cost to analyze your Amazon Web Services resources.
-
#update_event_sources_config(params = {}) ⇒ Struct
Enables or disables integration with a service that can be integrated with DevOps Guru.
-
#update_resource_collection(params = {}) ⇒ Struct
Updates the collection of resources that DevOps Guru analyzes.
-
#update_service_integration(params = {}) ⇒ Struct
Enables or disables integration with a service that can be integrated with DevOps Guru.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-devopsguru/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2463 2464 2465 |
# File 'lib/aws-sdk-devopsguru/client.rb', line 2463 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2466 2467 2468 |
# File 'lib/aws-sdk-devopsguru/client.rb', line 2466 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_notification_channel(params = {}) ⇒ Types::AddNotificationChannelResponse
Adds a notification channel to DevOps Guru. A notification channel is used to notify you about important DevOps Guru events, such as when an insight is generated.
If you use an Amazon SNS topic in another account, you must attach a policy to it that grants DevOps Guru permission to send it notifications. DevOps Guru adds the required policy on your behalf to send notifications using Amazon SNS in your account. DevOps Guru only supports standard SNS topics. For more information, see Permissions for Amazon SNS topics.
If you use an Amazon SNS topic that is encrypted by an Amazon Web Services Key Management Service customer-managed key (CMK), then you must add permissions to the CMK. For more information, see Permissions for Amazon Web Services KMS–encrypted Amazon SNS topics.
86 |
# File 'sig/client.rbs', line 86
def add_notification_channel: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2436 2437 2438 2439 2440 2441 2442 2443 2444 2445 2446 2447 2448 2449 2450 2451 2452 |
# File 'lib/aws-sdk-devopsguru/client.rb', line 2436 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::DevOpsGuru') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-devopsguru' context[:gem_version] = '1.77.0' Seahorse::Client::Request.new(handlers, context) end |
#delete_insight(params = {}) ⇒ Struct
Deletes the insight along with the associated anomalies, events and recommendations.
103 |
# File 'sig/client.rbs', line 103
def delete_insight: (
|
#describe_account_health(params = {}) ⇒ Types::DescribeAccountHealthResponse
Returns the number of open reactive insights, the number of open proactive insights, and the number of metrics analyzed in your Amazon Web Services account. Use these numbers to gauge the health of operations in your Amazon Web Services account.
117 |
# File 'sig/client.rbs', line 117
def describe_account_health: (
|
#describe_account_overview(params = {}) ⇒ Types::DescribeAccountOverviewResponse
For the time range passed in, returns the number of open reactive insight that were created, the number of open proactive insights that were created, and the Mean Time to Recover (MTTR) for all closed reactive insights.
128 |
# File 'sig/client.rbs', line 128
def describe_account_overview: (
|
#describe_anomaly(params = {}) ⇒ Types::DescribeAnomalyResponse
Returns details about an anomaly that you specify using its ID.
140 |
# File 'sig/client.rbs', line 140
def describe_anomaly: (
|
#describe_event_sources_config(params = {}) ⇒ Types::DescribeEventSourcesConfigResponse
Returns the integration status of services that are integrated with DevOps Guru as Consumer via EventBridge. The one service that can be integrated with DevOps Guru is Amazon CodeGuru Profiler, which can produce proactive recommendations which can be stored and viewed in DevOps Guru.
151 |
# File 'sig/client.rbs', line 151
def describe_event_sources_config: (
|
#describe_feedback(params = {}) ⇒ Types::DescribeFeedbackResponse
Returns the most recent feedback submitted in the current Amazon Web Services account and Region.
160 |
# File 'sig/client.rbs', line 160
def describe_feedback: (
|
#describe_insight(params = {}) ⇒ Types::DescribeInsightResponse
Returns details about an insight that you specify using its ID.
171 |
# File 'sig/client.rbs', line 171
def describe_insight: (
|
#describe_organization_health(params = {}) ⇒ Types::DescribeOrganizationHealthResponse
Returns active insights, predictive insights, and resource hours analyzed in last hour.
185 |
# File 'sig/client.rbs', line 185
def describe_organization_health: (
|
#describe_organization_overview(params = {}) ⇒ Types::DescribeOrganizationOverviewResponse
Returns an overview of your organization's history based on the specified time range. The overview includes the total reactive and proactive insights.
197 |
# File 'sig/client.rbs', line 197
def describe_organization_overview: (
|
#describe_organization_resource_collection_health(params = {}) ⇒ Types::DescribeOrganizationResourceCollectionHealthResponse
Provides an overview of your system's health. If additional member
accounts are part of your organization, you can filter those accounts
using the AccountIds field.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
214 |
# File 'sig/client.rbs', line 214
def describe_organization_resource_collection_health: (
|
#describe_resource_collection_health(params = {}) ⇒ Types::DescribeResourceCollectionHealthResponse
Returns the number of open proactive insights, open reactive insights, and the Mean Time to Recover (MTTR) for all closed insights in resource collections in your account. You specify the type of Amazon Web Services resources collection. The two types of Amazon Web Services resource collections supported are Amazon Web Services CloudFormation stacks and Amazon Web Services resources that contain the same Amazon Web Services tag. DevOps Guru can be configured to analyze the Amazon Web Services resources that are defined in the stacks or that are tagged using the same tag key. You can specify up to 500 Amazon Web Services CloudFormation stacks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
231 |
# File 'sig/client.rbs', line 231
def describe_resource_collection_health: (
|
#describe_service_integration(params = {}) ⇒ Types::DescribeServiceIntegrationResponse
Returns the integration status of services that are integrated with DevOps Guru. The one service that can be integrated with DevOps Guru is Amazon Web Services Systems Manager, which can be used to create an OpsItem for each generated insight.
242 |
# File 'sig/client.rbs', line 242
def describe_service_integration: (
|
#get_cost_estimation(params = {}) ⇒ Types::GetCostEstimationResponse
Returns an estimate of the monthly cost for DevOps Guru to analyze your Amazon Web Services resources. For more information, see Estimate your Amazon DevOps Guru costs and Amazon DevOps Guru pricing.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
256 |
# File 'sig/client.rbs', line 256
def get_cost_estimation: (
|
#get_resource_collection(params = {}) ⇒ Types::GetResourceCollectionResponse
Returns lists Amazon Web Services resources that are of the specified resource collection type. The two types of Amazon Web Services resource collections supported are Amazon Web Services CloudFormation stacks and Amazon Web Services resources that contain the same Amazon Web Services tag. DevOps Guru can be configured to analyze the Amazon Web Services resources that are defined in the stacks or that are tagged using the same tag key. You can specify up to 500 Amazon Web Services CloudFormation stacks.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
267 |
# File 'sig/client.rbs', line 267
def get_resource_collection: (
|
#list_anomalies_for_insight(params = {}) ⇒ Types::ListAnomaliesForInsightResponse
Returns a list of the anomalies that belong to an insight that you specify using its ID.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
280 |
# File 'sig/client.rbs', line 280
def list_anomalies_for_insight: (
|
#list_anomalous_log_groups(params = {}) ⇒ Types::ListAnomalousLogGroupsResponse
Returns the list of log groups that contain log anomalies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
304 |
# File 'sig/client.rbs', line 304
def list_anomalous_log_groups: (
|
#list_events(params = {}) ⇒ Types::ListEventsResponse
Returns a list of the events emitted by the resources that are evaluated by DevOps Guru. You can use filters to specify which events are returned.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
317 |
# File 'sig/client.rbs', line 317
def list_events: (
|
#list_insights(params = {}) ⇒ Types::ListInsightsResponse
Returns a list of insights in your Amazon Web Services account. You
can specify which insights are returned by their start time and status
(ONGOING, CLOSED, or ANY).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
342 |
# File 'sig/client.rbs', line 342
def list_insights: (
|
#list_monitored_resources(params = {}) ⇒ Types::ListMonitoredResourcesResponse
Returns the list of all log groups that are being monitored and tagged by DevOps Guru.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
355 |
# File 'sig/client.rbs', line 355
def list_monitored_resources: (
|
#list_notification_channels(params = {}) ⇒ Types::ListNotificationChannelsResponse
Returns a list of notification channels configured for DevOps Guru. Each notification channel is used to notify you when DevOps Guru generates an insight that contains information about how to improve your operations. The one supported notification channel is Amazon Simple Notification Service (Amazon SNS).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
371 |
# File 'sig/client.rbs', line 371
def list_notification_channels: (
|
#list_organization_insights(params = {}) ⇒ Types::ListOrganizationInsightsResponse
Returns a list of insights associated with the account or OU Id.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
383 |
# File 'sig/client.rbs', line 383
def list_organization_insights: (
|
#list_recommendations(params = {}) ⇒ Types::ListRecommendationsResponse
Returns a list of a specified insight's recommendations. Each recommendation includes a list of related metrics and a list of related events.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
398 |
# File 'sig/client.rbs', line 398
def list_recommendations: (
|
#put_feedback(params = {}) ⇒ Struct
Collects customer feedback about the specified insight.
410 |
# File 'sig/client.rbs', line 410
def put_feedback: (
|
#remove_notification_channel(params = {}) ⇒ Struct
Removes a notification channel from DevOps Guru. A notification channel is used to notify you when DevOps Guru generates an insight that contains information about how to improve your operations.
422 |
# File 'sig/client.rbs', line 422
def remove_notification_channel: (
|
#search_insights(params = {}) ⇒ Types::SearchInsightsResponse
Returns a list of insights in your Amazon Web Services account. You
can specify which insights are returned by their start time, one or
more statuses (ONGOING or CLOSED), one or more severities (LOW,
MEDIUM, and HIGH), and type (REACTIVE or PROACTIVE).
Use the Filters parameter to specify status and severity search
parameters. Use the Type parameter to specify REACTIVE or
PROACTIVE in your search.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
434 |
# File 'sig/client.rbs', line 434
def search_insights: (
|
#search_organization_insights(params = {}) ⇒ Types::SearchOrganizationInsightsResponse
Returns a list of insights in your organization. You can specify which
insights are returned by their start time, one or more statuses
(ONGOING, CLOSED, and CLOSED), one or more severities (LOW,
MEDIUM, and HIGH), and type (REACTIVE or PROACTIVE).
Use the Filters parameter to specify status and severity search
parameters. Use the Type parameter to specify REACTIVE or
PROACTIVE in your search.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
460 |
# File 'sig/client.rbs', line 460
def search_organization_insights: (
|
#start_cost_estimation(params = {}) ⇒ Struct
Starts the creation of an estimate of the monthly cost to analyze your Amazon Web Services resources.
484 |
# File 'sig/client.rbs', line 484
def start_cost_estimation: (
|
#update_event_sources_config(params = {}) ⇒ Struct
Enables or disables integration with a service that can be integrated with DevOps Guru. The one service that can be integrated with DevOps Guru is Amazon CodeGuru Profiler, which can produce proactive recommendations which can be stored and viewed in DevOps Guru.
504 |
# File 'sig/client.rbs', line 504
def update_event_sources_config: (
|
#update_resource_collection(params = {}) ⇒ Struct
Updates the collection of resources that DevOps Guru analyzes. The two types of Amazon Web Services resource collections supported are Amazon Web Services CloudFormation stacks and Amazon Web Services resources that contain the same Amazon Web Services tag. DevOps Guru can be configured to analyze the Amazon Web Services resources that are defined in the stacks or that are tagged using the same tag key. You can specify up to 500 Amazon Web Services CloudFormation stacks. This method also creates the IAM role required for you to use DevOps Guru.
517 |
# File 'sig/client.rbs', line 517
def update_resource_collection: (
|
#update_service_integration(params = {}) ⇒ Struct
Enables or disables integration with a service that can be integrated with DevOps Guru. The one service that can be integrated with DevOps Guru is Amazon Web Services Systems Manager, which can be used to create an OpsItem for each generated insight.
537 |
# File 'sig/client.rbs', line 537
def update_service_integration: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2456 2457 2458 |
# File 'lib/aws-sdk-devopsguru/client.rb', line 2456 def waiter_names [] end |