Class: Aws::DevOpsGuru::Types::AnomalousLogGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsguru/types.rb

Overview

An Amazon CloudWatch log group that contains log anomalies and is used to generate an insight.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#impact_end_timeTime

The time the anomalous log events stopped.



150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-devopsguru/types.rb', line 150

class AnomalousLogGroup < Struct.new(
  :log_group_name,
  :impact_start_time,
  :impact_end_time,
  :number_of_log_lines_scanned,
  :log_anomaly_showcases)
  SENSITIVE = []
  include Aws::Structure
end

#impact_start_timeTime

The time the anomalous log events began. The impact start time indicates the time of the first log anomaly event that occurs.



150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-devopsguru/types.rb', line 150

class AnomalousLogGroup < Struct.new(
  :log_group_name,
  :impact_start_time,
  :impact_end_time,
  :number_of_log_lines_scanned,
  :log_anomaly_showcases)
  SENSITIVE = []
  include Aws::Structure
end

#log_anomaly_showcasesArray<Types::LogAnomalyShowcase>

The log anomalies in the log group. Each log anomaly displayed represents a cluster of similar anomalous log events.



150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-devopsguru/types.rb', line 150

class AnomalousLogGroup < Struct.new(
  :log_group_name,
  :impact_start_time,
  :impact_end_time,
  :number_of_log_lines_scanned,
  :log_anomaly_showcases)
  SENSITIVE = []
  include Aws::Structure
end

#log_group_nameString

The name of the CloudWatch log group.



150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-devopsguru/types.rb', line 150

class AnomalousLogGroup < Struct.new(
  :log_group_name,
  :impact_start_time,
  :impact_end_time,
  :number_of_log_lines_scanned,
  :log_anomaly_showcases)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_log_lines_scannedInteger

The number of log lines that were scanned for anomalous log events.



150
151
152
153
154
155
156
157
158
# File 'lib/aws-sdk-devopsguru/types.rb', line 150

class AnomalousLogGroup < Struct.new(
  :log_group_name,
  :impact_start_time,
  :impact_end_time,
  :number_of_log_lines_scanned,
  :log_anomaly_showcases)
  SENSITIVE = []
  include Aws::Structure
end