Class: Aws::DevOpsGuru::Types::ListInsightsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsguru/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.



1860
1861
1862
1863
1864
1865
1866
# File 'lib/aws-sdk-devopsguru/types.rb', line 1860

class ListInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.



1860
1861
1862
1863
1864
1865
1866
# File 'lib/aws-sdk-devopsguru/types.rb', line 1860

class ListInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#status_filterTypes::ListInsightsStatusFilter

A filter used to filter the returned insights by their status. You can specify one status filter.



1860
1861
1862
1863
1864
1865
1866
# File 'lib/aws-sdk-devopsguru/types.rb', line 1860

class ListInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end