Class: Aws::DevOpsGuru::Types::ListNotificationChannelsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsguru/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.



1991
1992
1993
1994
1995
# File 'lib/aws-sdk-devopsguru/types.rb', line 1991

class ListNotificationChannelsRequest < Struct.new(
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end