Class: Aws::DevOpsGuru::Types::ListOrganizationInsightsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsguru/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_idsArray<String>

The ID of the Amazon Web Services account.



2040
2041
2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-devopsguru/types.rb', line 2040

class ListOrganizationInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :account_ids,
  :organizational_unit_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value.



2040
2041
2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-devopsguru/types.rb', line 2040

class ListOrganizationInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :account_ids,
  :organizational_unit_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The pagination token to use to retrieve the next page of results for this operation. If this value is null, it retrieves the first page.



2040
2041
2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-devopsguru/types.rb', line 2040

class ListOrganizationInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :account_ids,
  :organizational_unit_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#organizational_unit_idsArray<String>

The ID of the organizational unit.



2040
2041
2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-devopsguru/types.rb', line 2040

class ListOrganizationInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :account_ids,
  :organizational_unit_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#status_filterTypes::ListInsightsStatusFilter

A filter used by ListInsights to specify which insights to return.



2040
2041
2042
2043
2044
2045
2046
2047
2048
# File 'lib/aws-sdk-devopsguru/types.rb', line 2040

class ListOrganizationInsightsRequest < Struct.new(
  :status_filter,
  :max_results,
  :account_ids,
  :organizational_unit_ids,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end