Class: Aws::DevOpsGuru::Types::SearchInsightsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-devopsguru/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

The pagination token to use to retrieve the next page of results for this operation. If there are no more pages, this value is null.



4108
4109
4110
4111
4112
4113
4114
# File 'lib/aws-sdk-devopsguru/types.rb', line 4108

class SearchInsightsResponse < Struct.new(
  :proactive_insights,
  :reactive_insights,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#proactive_insightsArray<Types::ProactiveInsightSummary>

The returned proactive insights.



4108
4109
4110
4111
4112
4113
4114
# File 'lib/aws-sdk-devopsguru/types.rb', line 4108

class SearchInsightsResponse < Struct.new(
  :proactive_insights,
  :reactive_insights,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#reactive_insightsArray<Types::ReactiveInsightSummary>

The returned reactive insights.



4108
4109
4110
4111
4112
4113
4114
# File 'lib/aws-sdk-devopsguru/types.rb', line 4108

class SearchInsightsResponse < Struct.new(
  :proactive_insights,
  :reactive_insights,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end